==> sql-ledger_2.4.7.orig.tar.gz: sql-ledger/sql/Traditional-Chinese_Default-chart.sql <==
-- Default chart of accounts -- sample only
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2190','Iұo|','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2600','t','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3300','ѥꥻ','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3500','Odվl','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4000','Pվl','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4300','Ը߬վl','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4400','䥦վl','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5000','fP','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5400','~X','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5600','`κ޲zX','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1205','bbƩ','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1000','yʸ겣','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1800','ꥻ겣','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1825','֭pI - ˿Xγ].','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1845','֭pI - Bu','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2000','yʭt','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2620','Ȧɴ','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3600','yʬվl','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2160','Iq|','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3590','Odվl - h~','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3350','qѥ','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1500','sf겣','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5615','siP','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5790','u','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5700','줽Ϋ~','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5800','vQ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5610','|pk','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5685','OI','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5660','X','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5620','ab','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5680','ұo|','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5690','QλȦO','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5410','~','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5420','OIX','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5430','hX','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5440','vX','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5470','u֧Q','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4030','P / n','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4440','Q','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5100','BO','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5760','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1530','ws / n','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1540','ws / Gťs','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4040','P / Gťs','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5030','fP / n','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5010','','A','','E','AP_amount:IC_cogs:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5040','fP / Gťs','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1065','sΪ','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1820','줽Ǹ˿Xγ]','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5785','ȶOήT','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2680','ѪFU','A','','L','AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5795','UO','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5780','qHO','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5781','suO','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5765','׺޲zO','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2311','a|','A','','L','AR_tax:AP_tax:IC_taxpart:IC_taxservice:CT_tax');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4430','BPO','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1520','ws / w','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5020','fP / w','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2100','Ib','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1840','Bu','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4330','{]p','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4020','P / w','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4320','Ը','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1200','b','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1061','䲼Y','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2310','ӫ~Aȵ|','A','','L','AR_tax:AP_tax:IC_taxpart:IC_taxservice:CT_tax');
--
-- exchange rate
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4450','Foreign Exchange Gain','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5810','Foreign Exchange Loss','A','','E','');
--
insert into tax (chart_id,rate) values ((select id from chart where accno = '2310'),0.07);
insert into tax (chart_id,rate) values ((select id from chart where accno = '2311'),0.08);
--
update defaults set inventory_accno_id = (select id from chart where accno = '1520'), income_accno_id = (select id from chart where accno = '4020'), expense_accno_id = (select id from chart where accno = '5010'), fxgain_accno_id = (select id from chart where accno = '4450'), fxloss_accno_id = (select id from chart where accno = '5810'), curr = 'USD', weightunit = 'kg';
--

==> sql-ledger-2.8.5.tar.gz: sql-ledger/sql/Traditional-Chinese_Default-chart.sql <==
-- Default chart of accounts -- sample only
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2190','Iұo|','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2600','t','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3300','ѥꥻ','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3500','Odվl','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4000','Pվl','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4300','Ը߬վl','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4400','䥦վl','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5000','fP','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5400','~X','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5600','`κ޲zX','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1205','bbƩ','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1000','yʸ겣','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1800','ꥻ겣','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link,contra) values ('1825','֭pI - ˿Xγ].','A','','A','','1');
insert into chart (accno,description,charttype,gifi_accno,category,link,contra) values ('1845','֭pI - Bu','A','','A','','1');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2000','yʭt','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2620','Ȧɴ','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3600','yʬվl','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2160','Iq|','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3590','Odվl - h~','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3350','qѥ','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1500','sf겣','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5615','siP','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5790','u','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5700','줽Ϋ~','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5800','vQ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5610','|pk','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5685','OI','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5660','X','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5620','ab','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5680','ұo|','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5690','QλȦO','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5410','~','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5420','OIX','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5430','hX','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5440','vX','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5470','u֧Q','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4030','P / n','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4440','Q','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5100','BO','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5760','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1530','ws / n','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1540','ws / Gťs','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4040','P / Gťs','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5030','fP / n','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5010','','A','','E','AP_amount:IC_cogs:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5040','fP / Gťs','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1065','sΪ','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1820','줽Ǹ˿Xγ]','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5785','ȶOήT','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2680','ѪFU','A','','L','AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5795','UO','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5780','qHO','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5781','suO','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5765','׺޲zO','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2311','a|','A','','L','AR_tax:AP_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4430','BPO','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1520','ws / w','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5020','fP / w','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2100','Ib','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1840','Bu','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4330','{]p','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4020','P / w','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4320','Ը','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1200','b','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1061','䲼Y','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2310','ӫ~Aȵ|','A','','L','AR_tax:AP_tax:IC_taxpart:IC_taxservice');
--
-- exchange rate
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4450','Foreign Exchange Gain','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5810','Foreign Exchange Loss','A','','E','');
--
insert into tax (chart_id,rate) values ((select id from chart where accno = '2310'),0.07);
insert into tax (chart_id,rate) values ((select id from chart where accno = '2311'),0.08);
--
INSERT INTO defaults (fldname, fldvalue) VALUES ('inventory_accno_id', (SELECT id FROM chart WHERE accno = '1520'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('income_accno_id', (SELECT id FROM chart WHERE accno = '4020'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('expense_accno_id', (SELECT id FROM chart WHERE accno = '5010'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('fxgain_accno_id', (SELECT id FROM chart WHERE accno = '4450'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('fxloss_accno_id', (SELECT id FROM chart WHERE accno = '5810'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('currencies', 'CNY:EUR:USD');
INSERT INTO defaults (fldname, fldvalue) VALUES ('weightunit', 'kg');
